@@ -71,7 +71,8 @@ class HostController:
                                                 conn=emulation_env_config.get_connection(ip=ip))
 
         if constants.COMMANDS.SEARCH_HOST_MANAGER not in str(o):
-            logger.info(f"Host manager is not running on: {ip}, starting it. Output of {cmd} was: {str(o)}")
+            logger.info(f"Host manager is not running on: {ip}, starting it. Output of {cmd} was: {str(o)}, "
+                        f"err output was: {str(e)}")
 
             # Stop old background job if running
             cmd = (constants.COMMANDS.SUDO + constants.COMMANDS.SPACE_DELIM + constants.COMMANDS.PKILL +
@@ -217,8 +218,8 @@ class HostController:
 
         if emulation_env_config.sdn_controller_config is not None \
                 and emulation_env_config.sdn_controller_config.container.physical_host_ip == physical_server_ip:
-            # Start packetbeat on the SDN controller container
-            HostController.start_packetbeat(
+            # Start filebeat on the SDN controller container
+            HostController.start_filebeat(
                 emulation_env_config=emulation_env_config,
                 ips=([emulation_env_config.sdn_controller_config.container.docker_gw_bridge_ip] +
                      emulation_env_config.sdn_controller_config.container.get_ips()),
@@ -703,8 +704,7 @@ class HostController:
         host_monitor_dto = HostController.get_host_monitor_thread_status_by_port_and_ip(
             ip=ips[0], port=emulation_env_config.host_manager_config.host_manager_port)
         if not host_monitor_dto.filebeat_running:
-            logger.info(
-                f"Filebeat is not running on {ips[0]}, starting it.")
+            logger.info(f"Filebeat is not running on {ips[0]}, starting it.")
             # Open a gRPC session
             with grpc.insecure_channel(
                     f'{ips[0]}:{emulation_env_config.host_manager_config.host_manager_port}') as channel:
